@@ -1,12 +1,14 @@
 package PDK::Device::Cisco::Nxos;
 
+use utf8;
 use v5.30;
 use Moose;
 use Expect qw'exp_continue';
 use Carp   qw'croak';
-extends 'PDK::Device::Cisco';
 use namespace::autoclean;
 
+extends 'PDK::Device::Cisco';
+
 sub ftpConfig {
   my ($self, $hostname, $server, $username, $password) = @_;
 
@@ -25,12 +27,7 @@ sub ftpConfig {
 
   my $command = "copy running-config ftp://$username\@$server/$self->{month}/$self->{date}/";
 
-  if (!!$hostname) {
-    $command .= "${hostname}_${host}.txt";
-  }
-  else {
-    $command .= "$host.txt";
-  }
+  $command .= $hostname ? "$hostname\_$host.txt'" : "$host.txt";
 
   my $exp    = $self->{exp};
   my $result = $exp->match() || '';
@@ -57,16 +54,15 @@ sub ftpConfig {
     ],
     [
       eof => sub {
-        croak("执行[$command/尝试FTP备份配置]，与设备 $self->{host} 会话丢失，连接被意外关闭！原因：" . $exp->before());
+        croak("[$command/尝试FTP备份配置] 与设备 $self->{host} 会话丢失，连接被意外关闭！" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[$command/尝试FTP备份配置]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
+        croak("[$command/尝试FTP备份配置] 与设备 $self->{host} 会话超时，请检查网络连接或服务器状态");
       }
     ],
   );
-
   croak($ret[3]) if defined $ret[1];
 
   @ret = $exp->expect(
@@ -90,16 +86,15 @@ sub ftpConfig {
     ],
     [
       eof => sub {
-        croak("执行[$command/检查备份任务是否完成]，与设备 $self->{host} 会话丢失，连接被意外关闭！原因：" . $exp->before());
+        croak("[$command/检查备份任务是否完成] 与设备 $self->{host} 会话丢失，连接被意外关闭！" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[$command/检查备份任务是否完成]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
+        croak("[$command/检查备份任务是否完成] 与设备 $self->{host} 会话超时，请检查网络连接或服务器状态");
       }
     ],
   );
-
   croak($ret[3]) if defined $ret[1];
 
   return {success => 1, config => $result};
